@@ -14,7 +14,7 @@ Usage::
     client: RDSDataServiceClient = boto3.client("rds-data")
     session_client: RDSDataServiceClient = session.client("rds-data")
 """
-from mypy_boto3_rds_data.client import RDSDataServiceClient as Client, RDSDataServiceClient
+from mypy_boto3_rds_data.client import RDSDataServiceClient, RDSDataServiceClient as Client
 
 
 __all__ = ("Client", "RDSDataServiceClient")
